# MarkdownConvertor

In this repo, we develop a little tool which can convert a markdown file into a pdf file or html file.

We use three libraries:
- markdown: A lib which can read markdown files. For more details, visit their [home page](https://pypi.org/project/Markdown/)
- weasyprint: It is a smart solution helping web developers to create PDF documents. It turns simple HTML pages into pdf files. [home page](https://pypi.org/project/weasyprint/)
- pygments: Pygments is a syntax highlighting package written in Python.

## Usage

